summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
-rw-r--r--src/mame/drivers/gts80.cpp61
-rw-r--r--src/mame/mame.lst1
2 files changed, 37 insertions, 25 deletions
diff --git a/src/mame/mame.lst b/src/mame/mame.lst
index 109785b23b4..fe5e4ac1a68 100644
--- a/src/mame/mame.lst
+++ b/src/mame/mame.lst
@@ -15645,6 +15645,7 @@ circusp //
cntforce //
eclipse //
forceii //
+grand8 //
hh //
hh_1 //
jamesb //
diff --git a/src/mame/drivers/gts80.cpp b/src/mame/drivers/gts80.cpp
index 5d0c92e076e..723592d7c69 100644
--- a/src/mame/drivers/gts80.cpp
+++ b/src/mame/drivers/gts80.cpp
@@ -637,6 +637,16 @@ ROM_START(panther7)
ROM_END
#endif
+ROM_START(grand8)
+ ROM_REGION(0x10000, "maincpu", 0)
+ ROM_LOAD("u2_80.bin", 0x2000, 0x1000, CRC(4f0bc7b1) SHA1(612cbacdca5cfa6ad23940796df3b7c385be79fe))
+ ROM_LOAD("u3_80.bin", 0x3000, 0x1000, CRC(1e69f9d0) SHA1(ad738cac2555830257b531e5e533b15362f624b9))
+ ROM_LOAD("652.cpu", 0x1000, 0x0800, CRC(5386e5fb) SHA1(822f47951b702f9c6a1ce674baaab0a596f34413))
+
+ ROM_REGION(0x2000, "r0sound:audiocpu", 0)
+ ROM_LOAD("grand8.bin", 0, 0x2000, CRC(b7cfaaae) SHA1(60eb4f9bc7b7d11ec6d353b0ae02484cf1c0c9ee))
+ROM_END
+
/*-------------------------------------------------------------------
/ Pink Panther #664
/-------------------------------------------------------------------*/
@@ -802,28 +812,29 @@ ROM_START(s80tst)
ROM_LOAD("80tst-s2.snd", 0x7800, 0x0800, CRC(1a4b1e9d) SHA1(18e7ffbdbdaf83ab1c8daa5fa5201d9f54390758))
ROM_END
-/* disp1 */GAME(1981, s80tst, 0, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "System 80 Test", MACHINE_IS_SKELETON_MECHANICAL)
-
-/* disp1 */GAME(1980, panthera, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Panthera", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1980, spidermn, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "The Amazing Spider-Man", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1980, circusp, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Circus", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1980, cntforce, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Counterforce", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1980, starrace, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Star Race", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp2 */GAME(1980, jamesb, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "James Bond (Timed Play)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp2 */GAME(1980, jamesb2, jamesb, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "James Bond (3/5-Ball)", MACHINE_IS_SKELETON_MECHANICAL)
-/* cust */GAME(1980, timeline, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Time Line", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1981, forceii, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Force II", MACHINE_IS_SKELETON_MECHANICAL)
-/* cust */GAME(1981, pnkpnthr, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Pink Panther", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1981, marsp, 0, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Mars - God of War", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1981, marspf, marsp, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Mars - God of War (French speech)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1981, marspp, marsp, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Mars - God of War (Prototype)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1981, vlcno_ax, 0, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Volcano", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1981, vlcno_1c, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Volcano (Sound Only set 1)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1981, vlcno_1b, vlcno_1c, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Volcano (Sound Only set 2)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp1 */GAME(1981, vlcno_1a, vlcno_1c, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Volcano (Sound Only set 3)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp2 */GAME(1981, blckhole, 0, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Black Hole (Rev. 4)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp2 */GAME(1981, blckhole2, blckhole, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Black Hole (Rev. 2)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp2 */GAME(1981, blckhols, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Black Hole (Sound Only)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp2 */GAME(1982, hh, 0, gts80_hh, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Haunted House (Rev. 2)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp2 */GAME(1982, hh_1, hh, gts80_hh, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Haunted House (Rev. 1)", MACHINE_IS_SKELETON_MECHANICAL)
-/* disp2 */GAME(1981, eclipse, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Eclipse", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1981, s80tst, 0, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "System 80 Test", MACHINE_IS_SKELETON_MECHANICAL)
+
+/* disp1 */GAME(1980, panthera, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Panthera", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1980, grand8, panthera, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Christian Tabart", "Le Grand 8", MACHINE_IS_SKELETON_MECHANICAL) // Panthera conversion
+/* disp1 */GAME(1980, spidermn, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "The Amazing Spider-Man", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1980, circusp, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Circus", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1980, cntforce, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Counterforce", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1980, starrace, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Star Race", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp2 */GAME(1980, jamesb, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "James Bond (Timed Play)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp2 */GAME(1980, jamesb2, jamesb, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "James Bond (3/5-Ball)", MACHINE_IS_SKELETON_MECHANICAL)
+/* cust */GAME(1980, timeline, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Time Line", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1981, forceii, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Force II", MACHINE_IS_SKELETON_MECHANICAL)
+/* cust */GAME(1981, pnkpnthr, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Pink Panther", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1981, marsp, 0, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Mars - God of War", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1981, marspf, marsp, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Mars - God of War (French speech)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1981, marspp, marsp, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Mars - God of War (Prototype)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1981, vlcno_ax, 0, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Volcano", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1981, vlcno_1c, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Volcano (Sound Only set 1)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1981, vlcno_1b, vlcno_1c, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Volcano (Sound Only set 2)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp1 */GAME(1981, vlcno_1a, vlcno_1c, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Volcano (Sound Only set 3)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp2 */GAME(1981, blckhole, 0, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Black Hole (Rev. 4)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp2 */GAME(1981, blckhole2, blckhole, gts80_ss, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Black Hole (Rev. 2)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp2 */GAME(1981, blckhols, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Black Hole (Sound Only)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp2 */GAME(1982, hh, 0, gts80_hh, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Haunted House (Rev. 2)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp2 */GAME(1982, hh_1, hh, gts80_hh, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Haunted House (Rev. 1)", MACHINE_IS_SKELETON_MECHANICAL)
+/* disp2 */GAME(1981, eclipse, 0, gts80_s, gts80, gts80_state, init_gts80, ROT0, "Gottlieb", "Eclipse", MACHINE_IS_SKELETON_MECHANICAL)